@@ -10,9 +10,9 @@ $disable_log='0';
 $disable_call_record='0';
 
 $checksum=0x56781234;
-$version="V1.7.2";
-$bdate="Build 201604";
-$vflag="110";
+$version="V1.8";
+$bdate="Build 201612";
+$vflag="112";
 
 define("__FOR_ARM__", 1);
 define("TYPE_SIM", 1);
@@ -49,5 +49,6 @@ define("IMEI", 81);
 define("SMS_CLIENT_ID", 82);
 
 define("IMEI_IMSI_INFO", 75);
+define("AUTO_DIAL", 131);
 
 ?>
