@@ -358,10 +358,36 @@
 	
 /*1.7 fixed memory of xchanged */
 
-/*1.7.1 add no connected call in call limit */
+/*1.7 add no connected call in call limit */
 	@$db->updatequery("ALTER TABLE  `sim` ADD  `count_limit_no_connect` BOOL NOT NULL");
 /*1.7.2 fixed bug of set fixed IMEI*/
+/*1.7.2-t add dial api*/
+	@$db->updatequery("ALTER TABLE  `call_record` ADD  `type` int(1) NOT NULL");
+	if(!$rs || $rs[0] < 111){
+		@$db->updatequery("ALTER TABLE `call_record` ADD INDEX (`type`)");
+		@$db->updatequery("update `system` set `version`='111'");
+	}
+/*1.8 add limit sms*/
+	@$db->updatequery("ALTER TABLE  `sim` ADD `limit_sms` int(11) NOT NULL default '-1'");
+	@$db->updatequery("ALTER TABLE  `sim` ADD `remain_sms` int(11) NOT NULL default '-1'");
+	@$db->updatequery("ALTER TABLE  `sim` ADD `period_remain_sms` int(11) NOT NULL default '-1'");
+	if(!$rs || $rs[0] < 112){
+		$query=@$db->updatequery("select period_limit,id from sim where 1");
+		while($row=$db->fetch_array($query)){
+			if($row['period_limit']){
+				$limit_all="";
+				$a=explode(";", $row['period_limit']);
+				foreach($a as $limit){ //each period
+					if(strlen($limit ))$limit_all.=$limit.",-1;";
+				}
+				//echo "update sim set period_limit='".$limit_all."' where id=$row[id]";
+				if(strlen($limit_all)) @$db->updatequery("update sim set period_limit='".$limit_all."' where id=$row[id]");
+			}
+		}
+		
+		@$db->updatequery("update `system` set `version`='112'");
+	}
+
 	echo "update done! <a href=''  target=_top>Return</a>";
 
-
 ?>
